@@ -1195,13 +1195,14 @@ pub(crate) fn getcwd(buf: &mut [u8]) -> io::Result<()> {
 }
 
 #[cfg(not(any(target_os = "fuchsia", target_os = "wasi")))]
-pub(crate) fn ttyname(dirfd: BorrowedFd<'_>, buf: &mut [u8]) -> io::Result<()> {
+pub(crate) fn ttyname(dirfd: BorrowedFd<'_>, buf: &mut [u8]) -> io::Result<usize> {
     unsafe {
         ret(libc::ttyname_r(
             borrowed_fd(dirfd),
             buf.as_mut_ptr().cast::<_>(),
             buf.len(),
-        ))
+        ))?;
+        Ok(CStr::from_ptr(buf.as_ptr().cast::<_>()).to_bytes().len())
     }
 }
 
@@ -1337,8 +1338,8 @@ pub(crate) unsafe fn munmap(ptr: *mut c_void, len: usize) -> io::Result<()> {
 
 /// # Safety
 ///
-/// `mremap` is primarily unsafe due to the `old_address` parameter, as anything
-/// working with memory pointed to by raw pointers is unsafe.
+/// `mremap` is primarily unsafe due to the `old_address` parameter, as
+/// anything working with memory pointed to by raw pointers is unsafe.
 #[cfg(target_os = "linux")]
 pub(crate) unsafe fn mremap(
     old_address: *mut c_void,
@@ -1885,7 +1886,7 @@ pub(crate) fn clock_gettime_dynamic(id: DynamicClockId) -> io::Result<Timespec>
 
             #[cfg(any(target_os = "android", target_os = "linux"))]
             DynamicClockId::Dynamic(fd) => {
-                use crate::io::AsRawFd;
+                use io::AsRawFd;
                 const CLOCKFD: i32 = 3;
                 (!fd.as_raw_fd() << 3) | CLOCKFD
             }
