@@ -6,29 +6,20 @@ use crate::imp::linux_raw::reg::{ArgReg, RetReg, SyscallNumber, A0, A1, A2, A3,
 //
 // First we declare the actual assembly routines with `reordered_*` names and
 // reorgered arguments.
+//
+// We don't define `_readonly` versions of these because we have no way to tell
+// Rust that calls to our outline assembly are readonly.
 extern "C" {
-    fn rsix_reordered_syscall0_readonly(nr: SyscallNumber) -> RetReg<R0>;
+    fn rsix_reordered_syscall0(nr: SyscallNumber) -> RetReg<R0>;
     fn rsix_reordered_syscall1(a0: ArgReg<A0>, nr: SyscallNumber) -> RetReg<R0>;
-    fn rsix_reordered_syscall1_readonly(a0: ArgReg<A0>, nr: SyscallNumber) -> RetReg<R0>;
     fn rsix_reordered_syscall1_noreturn(a0: ArgReg<A0>, nr: SyscallNumber) -> !;
     fn rsix_reordered_syscall2(a0: ArgReg<A0>, a1: ArgReg<A1>, nr: SyscallNumber) -> RetReg<R0>;
-    fn rsix_reordered_syscall2_readonly(
-        a0: ArgReg<A0>,
-        a1: ArgReg<A1>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall3(
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall3_readonly(
-        a0: ArgReg<A0>,
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall4(
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
@@ -36,13 +27,6 @@ extern "C" {
         a3: ArgReg<A3>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall4_readonly(
-        a0: ArgReg<A0>,
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a3: ArgReg<A3>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall5(
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
@@ -51,14 +35,6 @@ extern "C" {
         a4: ArgReg<A4>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall5_readonly(
-        a0: ArgReg<A0>,
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a3: ArgReg<A3>,
-        a4: ArgReg<A4>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall6(
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
@@ -68,15 +44,6 @@ extern "C" {
         a5: ArgReg<A5>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall6_readonly(
-        a0: ArgReg<A0>,
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a3: ArgReg<A3>,
-        a4: ArgReg<A4>,
-        a5: ArgReg<A5>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
 }
 
 // Then we define inline wrapper functions that do the reordering.
@@ -86,7 +53,7 @@ mod reorder {
     #[inline]
     #[must_use]
     pub(in crate::imp::linux_raw) unsafe fn syscall0_readonly(nr: SyscallNumber) -> RetReg<R0> {
-        rsix_reordered_syscall0_readonly(nr)
+        rsix_reordered_syscall0(nr)
     }
     #[inline]
     #[must_use]
@@ -102,7 +69,7 @@ mod reorder {
         nr: SyscallNumber,
         a0: ArgReg<A0>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall1_readonly(a0, nr)
+        rsix_reordered_syscall1(a0, nr)
     }
     #[inline]
     #[must_use]
@@ -128,7 +95,7 @@ mod reorder {
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall2_readonly(a0, a1, nr)
+        rsix_reordered_syscall2(a0, a1, nr)
     }
     #[inline]
     #[must_use]
@@ -148,7 +115,7 @@ mod reorder {
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall3_readonly(a0, a1, a2, nr)
+        rsix_reordered_syscall3(a0, a1, a2, nr)
     }
     #[inline]
     #[must_use]
@@ -170,7 +137,7 @@ mod reorder {
         a2: ArgReg<A2>,
         a3: ArgReg<A3>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall4_readonly(a0, a1, a2, a3, nr)
+        rsix_reordered_syscall4(a0, a1, a2, a3, nr)
     }
     #[inline]
     #[must_use]
@@ -194,7 +161,7 @@ mod reorder {
         a3: ArgReg<A3>,
         a4: ArgReg<A4>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall5_readonly(a0, a1, a2, a3, a4, nr)
+        rsix_reordered_syscall5(a0, a1, a2, a3, a4, nr)
     }
     #[inline]
     #[must_use]
@@ -220,7 +187,7 @@ mod reorder {
         a4: ArgReg<A4>,
         a5: ArgReg<A5>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall6_readonly(a0, a1, a2, a3, a4, a5, nr)
+        rsix_reordered_syscall6(a0, a1, a2, a3, a4, a5, nr)
     }
 }
 
