@@ -9,29 +9,20 @@ use crate::imp::linux_raw::vdso_wrappers::SyscallType;
 //
 // First we declare the actual assembly routines with `rsix_reordered_*`
 // names and reorgered arguments.
+//
+// We don't define `_readonly` versions of these because we have no way to tell
+// Rust that calls to our outline assembly are readonly.
 extern "fastcall" {
-    fn rsix_reordered_syscall0_readonly(nr: SyscallNumber) -> RetReg<R0>;
+    fn rsix_reordered_syscall0(nr: SyscallNumber) -> RetReg<R0>;
     fn rsix_reordered_syscall1(a0: ArgReg<A0>, nr: SyscallNumber) -> RetReg<R0>;
-    fn rsix_reordered_syscall1_readonly(a0: ArgReg<A0>, nr: SyscallNumber) -> RetReg<R0>;
     fn rsix_reordered_syscall1_noreturn(a0: ArgReg<A0>, nr: SyscallNumber) -> !;
     fn rsix_reordered_syscall2(a1: ArgReg<A1>, a0: ArgReg<A0>, nr: SyscallNumber) -> RetReg<R0>;
-    fn rsix_reordered_syscall2_readonly(
-        a1: ArgReg<A1>,
-        a0: ArgReg<A0>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall3(
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
         a0: ArgReg<A0>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall3_readonly(
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a0: ArgReg<A0>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall4(
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
@@ -39,13 +30,6 @@ extern "fastcall" {
         a3: ArgReg<A3>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall4_readonly(
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a0: ArgReg<A0>,
-        a3: ArgReg<A3>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall5(
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
@@ -54,14 +38,6 @@ extern "fastcall" {
         a4: ArgReg<A4>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall5_readonly(
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a0: ArgReg<A0>,
-        a3: ArgReg<A3>,
-        a4: ArgReg<A4>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
     fn rsix_reordered_syscall6(
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
@@ -71,15 +47,6 @@ extern "fastcall" {
         a5: ArgReg<A5>,
         nr: SyscallNumber,
     ) -> RetReg<R0>;
-    fn rsix_reordered_syscall6_readonly(
-        a1: ArgReg<A1>,
-        a2: ArgReg<A2>,
-        a0: ArgReg<A0>,
-        a3: ArgReg<A3>,
-        a4: ArgReg<A4>,
-        a5: ArgReg<A5>,
-        nr: SyscallNumber,
-    ) -> RetReg<R0>;
 }
 
 // Then we define inline wrapper functions that do the reordering.
@@ -89,7 +56,7 @@ mod reorder {
     #[inline]
     #[must_use]
     pub(in crate::imp::linux_raw) unsafe fn syscall0_readonly(nr: SyscallNumber) -> RetReg<R0> {
-        rsix_reordered_syscall0_readonly(nr)
+        rsix_reordered_syscall0(nr)
     }
     #[inline]
     #[must_use]
@@ -105,7 +72,7 @@ mod reorder {
         nr: SyscallNumber,
         a0: ArgReg<A0>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall1_readonly(a0, nr)
+        rsix_reordered_syscall1(a0, nr)
     }
     #[inline]
     #[must_use]
@@ -131,7 +98,7 @@ mod reorder {
         a0: ArgReg<A0>,
         a1: ArgReg<A1>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall2_readonly(a1, a0, nr)
+        rsix_reordered_syscall2(a1, a0, nr)
     }
     #[inline]
     #[must_use]
@@ -151,7 +118,7 @@ mod reorder {
         a1: ArgReg<A1>,
         a2: ArgReg<A2>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall3_readonly(a1, a2, a0, nr)
+        rsix_reordered_syscall3(a1, a2, a0, nr)
     }
     #[inline]
     #[must_use]
@@ -173,7 +140,7 @@ mod reorder {
         a2: ArgReg<A2>,
         a3: ArgReg<A3>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall4_readonly(a1, a2, a0, a3, nr)
+        rsix_reordered_syscall4(a1, a2, a0, a3, nr)
     }
     #[inline]
     #[must_use]
@@ -197,7 +164,7 @@ mod reorder {
         a3: ArgReg<A3>,
         a4: ArgReg<A4>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall5_readonly(a1, a2, a0, a3, a4, nr)
+        rsix_reordered_syscall5(a1, a2, a0, a3, a4, nr)
     }
     #[inline]
     #[must_use]
@@ -223,7 +190,7 @@ mod reorder {
         a4: ArgReg<A4>,
         a5: ArgReg<A5>,
     ) -> RetReg<R0> {
-        rsix_reordered_syscall6_readonly(a1, a2, a0, a3, a4, a5, nr)
+        rsix_reordered_syscall6(a1, a2, a0, a3, a4, a5, nr)
     }
 }
 
