@@ -3,8 +3,8 @@ mod types;
 
 #[cfg(target_vendor = "mustang")]
 pub(crate) use auxv::init;
-pub(super) use auxv::{exe_phdrs, sysinfo_ehdr};
-pub(crate) use auxv::{linux_execfn, linux_hwcap, page_size};
+pub(crate) use auxv::{exe_phdrs, linux_execfn, linux_hwcap, page_size};
+pub(super) use auxv::{exe_phdrs_slice, sysinfo_ehdr};
 pub use types::{
     MembarrierCommand, RawCpuid, RawGid, RawPid, RawUid, RawUname, Resource, EXIT_FAILURE,
     EXIT_SIGNALED_SIGABRT, EXIT_SUCCESS,
