@@ -3,8 +3,11 @@
 use crate::imp;
 use crate::io::{self, OwnedFd};
 use io_lifetimes::AsFd;
-#[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
-use std::ffi::OsString;
+#[cfg(any(
+    all(linux_raw, feature = "procfs"),
+    all(libc, not(any(target_os = "fuchsia", target_os = "wasi")))
+))]
+use {io_lifetimes::BorrowedFd, std::ffi::OsString};
 
 #[cfg(not(target_os = "wasi"))]
 pub use imp::io::DupFlags;
@@ -131,9 +134,22 @@ pub fn dup2_with<Fd: AsFd>(fd: &Fd, new: &OwnedFd, flags: DupFlags) -> io::Resul
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/ttyname.html
 /// [Linux]: https://man7.org/linux/man-pages/man3/ttyname.3.html
-#[cfg(not(any(target_os = "fuchsia", target_os = "wasi")))]
+#[cfg(any(
+    all(linux_raw, feature = "procfs"),
+    all(libc, not(any(target_os = "fuchsia", target_os = "wasi")))
+))]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "procfs")))]
 #[inline]
 pub fn ttyname<Fd: AsFd>(dirfd: &Fd, reuse: OsString) -> io::Result<OsString> {
+    let dirfd = dirfd.as_fd();
+    _ttyname(dirfd, reuse)
+}
+
+#[cfg(any(
+    all(linux_raw, feature = "procfs"),
+    all(libc, not(any(target_os = "fuchsia", target_os = "wasi")))
+))]
+fn _ttyname(dirfd: BorrowedFd<'_>, reuse: OsString) -> io::Result<OsString> {
     use std::os::unix::ffi::OsStringExt;
 
     // This code would benefit from having a better way to read into
@@ -143,10 +159,9 @@ pub fn ttyname<Fd: AsFd>(dirfd: &Fd, reuse: OsString) -> io::Result<OsString> {
     buffer.resize(256, 0_u8);
 
     loop {
-        match imp::syscalls::ttyname(dirfd.as_fd(), &mut buffer) {
+        match imp::syscalls::ttyname(dirfd, &mut buffer) {
             Err(imp::io::Error::RANGE) => buffer.resize(buffer.len() * 2, 0_u8),
-            Ok(_) => {
-                let len = buffer.iter().position(|x| *x == b'\0').unwrap();
+            Ok(len) => {
                 buffer.resize(len, 0_u8);
                 return Ok(OsString::from_vec(buffer));
             }
