@@ -3,10 +3,6 @@
 #[cfg(any(target_os = "android", target_os = "linux"))]
 mod id;
 
-#[cfg(linux_raw)]
-#[doc(hidden)]
-pub mod tls;
-
 #[cfg(linux_raw)]
 mod futex;
 
